///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//         
// Filename: JTC_NTSC_GFX_DRV_v002.c
//
// Author: JT Cook - http://www.avalondreams.com
// 
// Support file for 30x24 and 8 16x16 sprites
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// First and foremost, include the chip definition header
#include "p24HJ256GP206.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

// include local XGS API header files
#include "XGS_PIC_SYSTEM_V010.h"
#include "JTC_NTSC_GFX_DRV_v002.h"

// Tile map engine variables needed
unsigned char *g_TileSet; 			// 16-bit pointer to a Character set as 8x8 with 1 byte per pixel
unsigned char *g_TileMapBasePtr;	// 16-bit pointer to the tile map
Sprite *g_SpriteList;				// 16-bit pointer to sprite table records

// Initializes the graphics engine
void GFX_InitTile(unsigned char *TileData, unsigned char *TileMap, Sprite *SpriteTable)
{
	g_TileSet = TileData;
	g_TileMapBasePtr = TileMap;
	g_SpriteList = SpriteTable;
}

// Starts the timer1 interrupt which calls our assembly video driver code
void GFX_StartDrawing(int ScreenType)
{
	// Configure PORTB graphics section as an output
	PORTB &= ~(0x00FF);				// Set bits to 0
	TRISB &= ~(0x00FF);				// Set pins to output

	// Configure PORTF saturation controls for NTSC
	PORTF &= ~(0x03);				// Turn lower two bits to off RF0, RF1
	TRISF &= ~(0x03);				// Turn lower two bits to output

	TMR1 = 0;						// Clear the current timer value
	if(ScreenType == SCREEN_TYPE_NTSC)
		PR1 = 2723;						// Period = (2723+1 counts = 227 pixel clocks * 12) in a 3.57*12 Clock for NTSC
	else
		PR1 = 1399;						// Period = 1399+1 counts = 31.77 us using 22.69 nS Clock for VGA

	T1CONbits.TCS = 0;				// Use internal clock source
	IPC0bits.T1IP = 7;				// Set interrupt priority to 7 (0->7)
	IFS0bits.T1IF = 0;				// Clear interrupt flag in status register
	IEC0bits.T1IE = 1;				// Enable Timer1 interrupt
	T1CONbits.TON = 1;				// Turn the timer on
}

//fills the screen with a select character
void fill_screen(char digit)
{
 int n;
 for(n=0;n<(SCREEN_TILE_MAP_WIDTH*SCREEN_TILE_MAP_HEIGHT);n++)
  g_TileMapBasePtr[n]=digit; //fills screen
}

//places a tile
void draw_tile(int x, int y, char tile_pic)
{
  g_TileMapBasePtr[y*SCREEN_TILE_MAP_WIDTH+x]=tile_pic; //draw tile
}

